@@ -187,6 +187,11 @@ class Resource:
     def raw(self):
         return self._get_content()
 
+    def _get_path(self, field, path):
+        if path is None:
+            return field
+        return path
+
     def post(self, payload=None):
         """
         Perform a POST at the resource with the given payload.
@@ -211,6 +216,20 @@ class Resource:
             raise MissingOidException("The resource cannot be PATCHed.")
         return self._connector.patch(path, payload=payload)
 
+    def put(self, path=None, payload=None):
+        """
+        Perform a PUT at the resource or selected path with the given payload.
+
+        Args:
+          path: Custom path for PUT request.
+          payload: The contents of the PUT payload.
+        """
+        field = self._content.get("@odata.id")
+        path = self._get_path(field, path)
+        if not path:
+            raise MissingOidException("The resource cannot be PUT.")
+        return self._connector.put(path, payload=payload)
+
     def delete(self):
         """
         Perform a DELETE at the resource.
